==> pycate-0.1.5.tar.gz: pycate-0.1.5/pycate/handlers/edit_handler.py <==
# -*- coding:utf-8 -*-

import tornado.web
from config import cfg as c
from pycate.model.catalog_model import MCatalog
from pycate.core import base_handler
from torlite.core import tools
import config


class EditHandler(base_handler.PycateBaseHandler):
    def initialize(self, hinfo=''):
        self.init_condition(config.mongo_collection_name)
        self.mcat = MCatalog()

    def get(self, input=''):
        if len(input) == 36:
            inf = self.minfo.get_by_id(input)
            if inf is None:
                self.render('html/404.html')
                return
            self.toedit(input)
        else:
            self.render('html/404.html')

    def post(self, input=''):
        if len(input) == 36:
            self.update(input)

    def is_editable(self, info):

        if info['userid'] == self.userinfo.user_name:
            # 谁发布的谁编辑
            return True
        return False

    @tornado.web.authenticated
    def toedit(self, infoid):
        rec_info = self.minfo.get_by_id(infoid)

        if self.is_editable(rec_info):
            pass
        else:
            return
        catid = rec_info['catid'][0]

        kwd = {
            'catid': catid,
            'parentid': catid[:2] + '00',
            'parentname': self.mcat.get_by_id(catid[:2] + '00').catname,
            'catname': self.mcat.get_by_id(catid).catname,
            'parentlist': self.mcat.get_parent_list(),

        }
        self.render('{0}/autogen/edit/edit_{1}.html'.format(self.template_dir_name, catid),
                    kwd=kwd,
                    post_info=rec_info)

    @tornado.web.authenticated
    def update(self, par_uid):

        if self.userinfo.privilege[2] == '1':
            pass
        else:
            return

        post_data = self.minfo.get_by_id(par_uid)

        for key in self.request.arguments:
            post_data[key] = self.get_arguments(key)

        if 'extra_mianji' in post_data:
            mianji_flt = float(post_data['extra_mianji'][0])
            if 'extra_mianji' in post_data:
                if mianji_flt < 20:
                    post_data['extra_mianji1'] = [1]
                elif mianji_flt < 40:
                    post_data['extra_mianji1'] = [2]
                elif mianji_flt < 60:
                    post_data['extra_mianji1'] = [3]
                elif mianji_flt < 90:
                    post_data['extra_mianji1'] = [4]
                elif mianji_flt < 120:
                    post_data['extra_mianji1'] = [5]
                elif mianji_flt < 200:
                    post_data['extra_mianji1'] = [6]
                elif mianji_flt >= 200:
                    post_data['extra_mianji1'] = [7]

        ts = tools.timestamp()
        ts_str = str(ts)

        post_data['catname'] = self.mcat.get_by_id(post_data['catid'][0]).catname

        post_data['userid'] = self.userinfo.user_name
        post_data['def_uid'] = str(par_uid)
        post_data['update_time'] = ts
        post_data['def_update_time_str'] = ts_str

        post_data['def_refresh'] = 1
        post_data['def_refresh_out_time'] = ts + c.refresh_timeout
        post_data['def_valid'] = 1
        post_data['def_banned'] = 0
        post_data['keywords'] = [x.strip() for x in post_data['keywords'][0].split(',')]
        udi = self.minfo.update(par_uid, post_data)

        self.redirect('/list/{0}'.format(post_data['catid'][0]))

==> pycate-0.1.6.tar.gz: pycate-0.1.6/pycate/handlers/edit_handler.py <==
# -*- coding:utf-8 -*-

import tornado.web
from config import cfg as c
from pycate.model.catalog_model import MCatalog
from pycate.core import base_handler
from torlite.core import tools
import config
import time


class EditHandler(base_handler.PycateBaseHandler):
    def initialize(self, hinfo=''):
        self.init_condition(config.mongo_collection_name)
        self.mcat = MCatalog()

    def get(self, input=''):
        if len(input) == 36:
            inf = self.minfo.get_by_id(input)
            if inf is None:
                self.render('html/404.html')
                return
            self.toedit(input)
        else:
            self.render('html/404.html')

    def post(self, input=''):
        if len(input) == 36:
            self.update(input)

    def is_editable(self, info):
        if self.userinfo.privilege[4] == '1':
            return True
        return False

    @tornado.web.authenticated
    def toedit(self, infoid):
        rec_info = self.minfo.get_by_id(infoid)

        if self.is_editable(rec_info):
            pass
        else:
            return False
        catid = rec_info['catid'][0]

        kwd = {
            'catid': catid,
            'parentid': catid[:2] + '00',
            'parentname': self.mcat.get_by_id(catid[:2] + '00').catname,
            'catname': self.mcat.get_by_id(catid).catname,
            'parentlist': self.mcat.get_parent_list(),
            'userip':self.request.remote_ip

        }
        self.render('{0}/autogen/edit/edit_{1}.html'.format(self.template_dir_name, catid),
                    kwd=kwd,
                    post_info=rec_info)

    @tornado.web.authenticated
    def update(self, par_uid):

        if self.userinfo.privilege[2] == '1':
            pass
        else:
            return

        post_data = self.minfo.get_by_id(par_uid)

        for key in self.request.arguments:
            post_data[key] = self.get_arguments(key)

        if 'extra_mianji' in post_data:
            mianji_flt = float(post_data['extra_mianji'][0])
            if 'extra_mianji' in post_data:
                if mianji_flt < 20:
                    post_data['extra_mianji1'] = [1]
                elif mianji_flt < 40:
                    post_data['extra_mianji1'] = [2]
                elif mianji_flt < 60:
                    post_data['extra_mianji1'] = [3]
                elif mianji_flt < 90:
                    post_data['extra_mianji1'] = [4]
                elif mianji_flt < 120:
                    post_data['extra_mianji1'] = [5]
                elif mianji_flt < 200:
                    post_data['extra_mianji1'] = [6]
                elif mianji_flt >= 200:
                    post_data['extra_mianji1'] = [7]

        ts = tools.timestamp()


        post_data['catname'] = self.mcat.get_by_id(post_data['catid'][0]).catname

        post_data['userid'] = self.userinfo.user_name
        post_data['def_uid'] = str(par_uid)
        post_data['update_time'] = ts
        post_data['def_update_time_str'] =  time.localtime(ts)

        post_data['def_refresh'] = 1
        post_data['def_refresh_out_time'] = ts + c.refresh_timeout
        post_data['def_valid'] = 1
        post_data['def_banned'] = 0
        post_data['keywords'] = [x.strip() for x in post_data['keywords'][0].split(',')]

        self.minfo.update(par_uid, post_data)

        self.redirect('/list/{0}'.format(post_data['catid'][0]))
